@@ -17,7 +17,7 @@
 
 from warnings import warn
 from pyspark import keyword_only
-from ai.h2o.sparkling import Initializer
+from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OSupervisedAlgorithmWithFoldColumn import H2OSupervisedAlgorithmWithFoldColumn
 from ai.h2o.sparkling.ml.models.H2OGLMMOJOModel import H2OGLMMOJOModel
@@ -48,7 +48,6 @@ class H2OGLM(H2OGLMParams, H2OSupervisedAlgorithmWithFoldColumn, FamilyBasedH2OT
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  seed=-1,
                  family="AUTO",
                  randomFamily=None,
