@@ -6,7 +6,7 @@ import traceback
 
 import h2o
 from h2o.base import Keyed
-from h2o.exceptions import H2OValueError
+from h2o.exceptions import H2OValueError, H2OTypeError
 from h2o.job import H2OJob
 from h2o.model.extensions import has_extension
 from h2o.plot import decorate_plot_result, get_matplotlib_pyplot, RAISE_ON_FIGURE_ACCESS
@@ -234,16 +234,14 @@ class ModelBase(h2o_meta(Keyed)):
         >>> # Compute SHAP and pick the top two highest and top two lowest
         >>> m.predict_contributions(fr, top_n=2, bottom_n=2)
         """
-        assert_is_type(output_format, None, Enum("Original", "Compact"))
-        if not isinstance(test_data, h2o.H2OFrame): raise ValueError("test_data must be an instance of H2OFrame")
-        j = H2OJob(h2o.api("POST /4/Predictions/models/%s/frames/%s" % (self.model_id, test_data.frame_id),
-                           data={"predict_contributions": True,
-                                 "predict_contributions_output_format": output_format,
-                                 "top_n": top_n,
-                                 "bottom_n": bottom_n,
-                                 "compare_abs": compare_abs}), "contributions")
-        j.poll()
-        return h2o.get_frame(j.dest_key)
+        if has_extension(self, 'Contributions'):
+            return self._predict_contributions(test_data, output_format, top_n, bottom_n, compare_abs)
+        err_msg = "This model doesn't support calculation of feature contributions."
+        if has_extension(self, 'StandardCoef'):
+            err_msg += " When features are independent, you can use the coef() method to get coefficients"
+            err_msg += " for non-standardized data or coef_norm() to get coefficients for standardized data."
+            err_msg += " You can plot standardized coefficient magnitudes by calling std_coef_plot() on the model."
+        raise H2OTypeError(message=err_msg)
 
     def feature_frequencies(self, test_data):
         """
